URLCategorizationDatabaseClient class

Constructors

URLCategorizationDatabaseClient({required String apiKey, String? baseUrl, Client? httpClient, Duration timeout = const Duration(seconds: 30)})

Properties

apiKey → String
final
baseUrl → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeout → Duration
final

Methods

classify(String value) → Future<ApiResult>
close() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited